[![Tests](https://github.com/Link Digital/ckanext-bulk/workflows/tests.yml/badge.svg)](https://github.com/Link Digital/ckanext-bulk/actions/workflows/test.yml)

# ckanext-bulk

An extension that helps to perform bulk operations over CKAN entities, such as datasets, organizations and groups.

## Requirements

Compatibility with core CKAN versions:

| CKAN version | Compatible? |
|--------------|-------------|
| 2.9          | no          |
| 2.10         | yes         |
| 2.11         | yes         |
| master       | yes         |
